@@ -183,5 +183,8 @@ class Selenium(Scraper):
 
         return image_filename
 
+    def on_switch_to(self, element: any) -> None:
+        self.driver.switch_to.frame(element)
+
     def on_close(self):
         self.driver.quit()
\ No newline at end of file
